@@ -1,13 +1,16 @@
 from __future__ import annotations
 
 import inspect
+from typing import TYPE_CHECKING, Callable
 
 import rich.repr
 from rich.console import RenderableType
 
 from ._context import active_app
 from ._log import LogGroup, LogVerbosity
-from ._typing import TypeAlias
+
+if TYPE_CHECKING:
+    from typing_extensions import TypeAlias
 
 __all__ = ["log", "panic", "__version__"]  # type: ignore
 
