@@ -1,8 +1,10 @@
 from __future__ import annotations
 
 from abc import ABC, abstractmethod
+from dataclasses import dataclass
 from typing import TYPE_CHECKING, ClassVar, NamedTuple
 
+from ._spatial_map import SpatialMap
 from .geometry import Region, Size, Spacing
 
 if TYPE_CHECKING:
@@ -11,7 +13,55 @@ if TYPE_CHECKING:
     from .widget import Widget
 
 ArrangeResult: TypeAlias = "tuple[list[WidgetPlacement], set[Widget]]"
-DockArrangeResult: TypeAlias = "tuple[list[WidgetPlacement], set[Widget], Spacing]"
+
+
+@dataclass
+class DockArrangeResult:
+    placements: list[WidgetPlacement]
+    """A `WidgetPlacement` for every widget to describe it's location on screen."""
+    widgets: set[Widget]
+    """A set of widgets in the arrangement."""
+    spacing: Spacing
+    """Shared spacing around the widgets."""
+
+    _spatial_map: SpatialMap[WidgetPlacement] | None = None
+
+    @property
+    def spatial_map(self) -> SpatialMap[WidgetPlacement]:
+        """A lazy-calculated spatial map."""
+        if self._spatial_map is None:
+            self._spatial_map = SpatialMap()
+            self._spatial_map.insert(
+                (
+                    placement.region.grow(placement.margin),
+                    placement.fixed,
+                    placement,
+                )
+                for placement in self.placements
+            )
+
+        return self._spatial_map
+
+    @property
+    def total_region(self) -> Region:
+        """The total area occupied by the arrangement.
+
+        Returns:
+            A Region.
+        """
+        return self.spatial_map.total_region
+
+    def get_visible_placements(self, region: Region) -> list[WidgetPlacement]:
+        """Get the placements visible within the given region.
+
+        Args:
+            region: A region.
+
+        Returns:
+            Set of placements.
+        """
+        visible_placements = self.spatial_map.get_values_in_region(region)
+        return visible_placements
 
 
 class WidgetPlacement(NamedTuple):
@@ -61,7 +111,7 @@ class Layout(ABC):
             width = 0
         else:
             # Use a size of 0, 0 to ignore relative sizes, since those are flexible anyway
-            placements, _, _ = widget._arrange(Size(0, 0))
+            placements = widget._arrange(Size(0, 0)).placements
             width = max(
                 [
                     placement.region.right + placement.margin.right
@@ -89,7 +139,7 @@ class Layout(ABC):
             height = 0
         else:
             # Use a height of zero to ignore relative heights
-            placements, _, _ = widget._arrange(Size(width, 0))
+            placements = widget._arrange(Size(width, 0)).placements
             height = max(
                 [
                     placement.region.bottom + placement.margin.bottom
