@@ -8,10 +8,10 @@ from rich.segment import Segment
 from rich.style import Style
 
 from ._border import get_box, render_row
-from .filter import LineFilter
 from ._opacity import _apply_opacity
 from ._segment_tools import line_pad, line_trim
 from .color import Color
+from .filter import LineFilter
 from .geometry import Region, Size, Spacing
 from .renderables.text_opacity import TextOpacity
 from .renderables.tint import Tint
@@ -120,13 +120,12 @@ class StylesCache:
         )
         if widget.auto_links:
             hover_style = widget.hover_style
-            link_hover_style = widget.link_hover_style
             if (
-                link_hover_style
-                and hover_style._link_id
+                hover_style._link_id
                 and hover_style._meta
                 and "@click" in hover_style.meta
             ):
+                link_hover_style = widget.link_hover_style
                 if link_hover_style:
                     strips = [
                         strip.style_links(hover_style.link_id, link_hover_style)
