@@ -444,7 +444,7 @@ class App(Generic[ReturnType], DOMNode):
 
     @contextmanager
     def batch_update(self) -> Generator[None, None, None]:
-        """Suspend all repaints until the end of the batch."""
+        """A context manager to suspend all repaints until the end of the batch."""
         self._begin_batch()
         try:
             yield
@@ -460,10 +460,6 @@ class App(Generic[ReturnType], DOMNode):
         self._batch_count -= 1
         assert self._batch_count >= 0, "This won't happen if you use `batch_update`"
         if not self._batch_count:
-            try:
-                self.screen.check_idle()
-            except ScreenStackError:
-                pass
             self.check_idle()
 
     def animate(
